<script setup>
import { onMounted, ref, watchEffect, nextTick, onBeforeUnmount } from "vue";
import * as echarts from 'echarts';
import baseChart from "./BaseChart.vue";
import { toFixed } from '@/utils/toFixed.js';
import hexToRgba from '@/utils/hexToRgba.js';

const chart = ref(null);
const props = defineProps({
	title: {
		type: String,
		default: ''
	},
	unit: {
		type: String,
		default: ''
	},
	// barW: {
	//   type: [Number, String],
	//   default: 60,
	// },
});




const color = '#13ACBE';
const topColor = '#07FBFF';
const minColor = '#f00';
const maxColor = '#0f0';

function getMax(data) {
	let max = Math.max.apply(null, data) * 1.2;
	return toFixed(max, 1) || 1;
}


function getOptions(datas) {
  // {value, name}
	datas = datas || [];


	const option = {
		tooltip: {
			trigger: 'item',
			formatter: "{a} <br/>{b} : {c} ({d}%)"
		},
		series: [{
			name: '性能占比',
			type: 'pie',
			radius: '48%',
			center: ['50%', '50%'],
			clockwise: false,
			data: datas,
      label: {
        textStyle: {
          color: '#0ff',
          fontSize: 14,
        },
        // 自动调整重叠标签
        // autoAdjustOverlap: true,
        // 标签位置
        position: 'outside',
        // 标签文本样式
        formatter: '{b}:\n {d}% \n {c}'
      },
			labelLine: {
        length: 20,
        length2: 8,
        minTurnAngle: 40, // 最小角度,防止标签重叠 
        maxSurfaceAngle: 110, // 限制引导线与扇区法线的最大夹角
				show: true
			},
			itemStyle: {
					borderWidth: 2,
					borderColor: '#ffffff',
				emphasis: {
					borderWidth: 0,
					shadowBlur: 10,
					shadowOffsetX: 0,
					shadowColor: 'rgba(0, 0, 0, 0.5)'
				}
			},
      emptyCircleStyle: {
        color: '#73c0de',
        borderWidth: 0
      }
		}],
		color: [
			'#00acee',
			'#52cdd5',
			'#79d9f1',
			'#a7e7ff',
			'#c8efff'
		],
	};

	return option;
}

let myChart = null;
let chart_instance = null;

function initChart() {
	if (chart.value) {
		// myChart = chart.value.getChart();

		let option = getOptions();
		chart.value.setOption(option);
		chart_instance = chart.value.getChart();
	}
}

function updateChart(datas) {
	if (chart.value) {
		let option = getOptions(datas);
		chart.value.setOption(option);
	}
}

function getChart() {
	return chart_instance;
}

function getDataURL() {
	return chart.value.getDataURL();
}

defineExpose({
	getChart,
	getDataURL,
	updateChart
});

onMounted(() => {
	// console.log('line mounted', '=============');

	initChart();
});
</script>

<template>
  <div class="line-chart">
    <base-chart ref="chart"></base-chart>
  </div>
</template>

<style scoped>
.line-chart {
  width: 100%;
  height: 100%;
}
</style>
